@@ -5,14 +5,11 @@
 # you can obtain one at http://mozilla.org/MPL/2.0/.
 # SPDX-License-Identifier: MPL-2.0
 # This file is part of Grid2Op, Grid2Op a testbed platform to model sequential decision making in power systems.
-import os
 import numpy as np
 
-from grid2op.Action import BaseAction
 from grid2op.Converter.Converters import Converter
-from grid2op.dtypes import dt_float, dt_int
-import pdb
-import time
+from grid2op.dtypes import dt_int
+
 
 class ConnectivityConverter(Converter):
     """
