@@ -6,9 +6,12 @@
 # SPDX-License-Identifier: MPL-2.0
 # This file is part of Grid2Op, Grid2Op a testbed platform to model sequential decision making in power systems.
 
+from grid2op.Space import RandomObject
 
-class BaseOpponent(object):
+
+class BaseOpponent(RandomObject):
     def __init__(self, action_space):
+        RandomObject.__init__(self)
         self.action_space = action_space
         self._do_nothing = self.action_space()
 
