@@ -8,7 +8,6 @@
 
 import json
 import warnings
-from numpy import dtype
 import pdb
 
 from grid2op.tests.helper_path_test import *
@@ -16,19 +15,18 @@ from grid2op.tests.helper_path_test import *
 from grid2op.dtypes import dt_int, dt_float, dt_bool
 from grid2op.Exceptions import *
 from grid2op.Observation import ObservationSpace, CompleteObservation
-from grid2op.Chronics import ChronicsHandler, GridStateFromFile, GridStateFromFileWithForecasts
+from grid2op.Chronics import ChronicsHandler, GridStateFromFile
 from grid2op.Rules import RulesChecker
 from grid2op.Reward import L2RPNReward
 from grid2op.Parameters import Parameters
 from grid2op.Backend import PandaPowerBackend
 from grid2op.Environment import Environment
-from grid2op.MakeEnv import make_new
+from grid2op.MakeEnv import make
 
 # TODO add unit test for the proper update the backend in the observation [for now there is a "data leakage" as
 # the real backend is copied when the observation is built, but i need to make a test to check that's it's properly
 # copied]
 
-
 # temporary deactivation of all the failing test until simulate is fixed
 DEACTIVATE_FAILING_TEST = True
 
@@ -41,96 +39,51 @@ class TestLoadingBackendFunc(unittest.TestCase):
         """
         self.tolvect = 1e-2
         self.tol_one = 1e-5
-        self.game_rules = RulesChecker()
-        # pdb.set_trace()
-        self.rewardClass = L2RPNReward
-        self.reward_helper = self.rewardClass()
-        self.obsClass = CompleteObservation
-        self.parameters = Parameters()
-
-        # powergrid
-        self.backend = PandaPowerBackend()
-        self.path_matpower = PATH_DATA_TEST_PP
-        self.case_file = "test_case14.json"
-
-        # chronics
-        self.path_chron = os.path.join(PATH_CHRONICS, "chronics_with_forecast")
-        self.chronics_handler = ChronicsHandler(chronicsClass=GridStateFromFileWithForecasts, path=self.path_chron)
-
-        self.tolvect = 1e-2
-        self.tol_one = 1e-5
-        self.id_chron_to_back_load = np.array([0, 1, 10, 2, 3, 4, 5, 6, 7, 8, 9])
-
-        # force the verbose backend
-        self.backend.detailed_infos_for_cascading_failures = True
-
-        self.names_chronics_to_backend = {"loads": {"2_C-10.61": 'load_1_0', "3_C151.15": 'load_2_1',
-                                                    "14_C63.6": 'load_13_2', "4_C-9.47": 'load_3_3',
-                                                    "5_C201.84": 'load_4_4',
-                                                    "6_C-6.27": 'load_5_5', "9_C130.49": 'load_8_6',
-                                                    "10_C228.66": 'load_9_7',
-                                                    "11_C-138.89": 'load_10_8', "12_C-27.88": 'load_11_9',
-                                                    "13_C-13.33": 'load_12_10'},
-                                          "lines": {'1_2_1': '0_1_0', '1_5_2': '0_4_1', '9_10_16': '8_9_2',
-                                                    '9_14_17': '8_13_3',
-                                                    '10_11_18': '9_10_4', '12_13_19': '11_12_5', '13_14_20': '12_13_6',
-                                                    '2_3_3': '1_2_7', '2_4_4': '1_3_8', '2_5_5': '1_4_9',
-                                                    '3_4_6': '2_3_10',
-                                                    '4_5_7': '3_4_11', '6_11_11': '5_10_12', '6_12_12': '5_11_13',
-                                                    '6_13_13': '5_12_14', '4_7_8': '3_6_15', '4_9_9': '3_8_16',
-                                                    '5_6_10': '4_5_17',
-                                                    '7_8_14': '6_7_18', '7_9_15': '6_8_19'},
-                                          "prods": {"1_G137.1": 'gen_0_4', "3_G36.31": "gen_2_1", "6_G63.29": "gen_5_2",
-                                                    "2_G-56.47": "gen_1_0", "8_G40.43": "gen_7_3"},
-                                          }
-
-        # _parameters for the environment
-        self.env_params = Parameters()
-
-        self.env = Environment(init_grid_path=os.path.join(self.path_matpower, self.case_file),
-                               backend=self.backend,
-                               chronics_handler=self.chronics_handler,
-                               parameters=self.env_params,
-                               names_chronics_to_backend=self.names_chronics_to_backend,
-                               rewardClass=self.rewardClass)
 
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore")
+            self.env = make("rte_case14_test", test=True)
         self.dict_ = {'name_gen': ['gen_1_0', 'gen_2_1', 'gen_5_2', 'gen_7_3', 'gen_0_4'],
-                      'name_load': ['load_1_0', 'load_2_1', 'load_13_2', 'load_3_3', 'load_4_4', 'load_5_5', 'load_8_6',
-                                    'load_9_7', 'load_10_8', 'load_11_9', 'load_12_10'],
+                      'name_load': ['load_1_0', 'load_2_1', 'load_13_2', 'load_3_3', 'load_4_4',
+                                    'load_5_5', 'load_8_6', 'load_9_7', 'load_10_8', 'load_11_9', 'load_12_10'],
                       'name_line': ['0_1_0', '0_4_1', '8_9_2', '8_13_3', '9_10_4', '11_12_5', '12_13_6', '1_2_7',
                                     '1_3_8', '1_4_9', '2_3_10', '3_4_11', '5_10_12', '5_11_13', '5_12_14', '3_6_15',
                                     '3_8_16', '4_5_17', '6_7_18', '6_8_19'],
-                      'name_sub': ['sub_0', 'sub_1', 'sub_10', 'sub_11', 'sub_12', 'sub_13', 'sub_2', 'sub_3', 'sub_4',
-                                   'sub_5', 'sub_6', 'sub_7', 'sub_8', 'sub_9'],
+                      'name_sub': ['sub_0', 'sub_1', 'sub_10', 'sub_11', 'sub_12', 'sub_13', 'sub_2', 'sub_3',
+                                   'sub_4', 'sub_5', 'sub_6', 'sub_7', 'sub_8', 'sub_9'],
                       'sub_info': [3, 6, 4, 6, 5, 6, 3, 2, 5, 3, 3, 3, 4, 3],
                       'load_to_subid': [1, 2, 13, 3, 4, 5, 8, 9, 10, 11, 12],
                       'gen_to_subid': [1, 2, 5, 7, 0],
                       'line_or_to_subid': [0, 0, 8, 8, 9, 11, 12, 1, 1, 1, 2, 3, 5, 5, 5, 3, 3, 4, 6, 6],
                       'line_ex_to_subid': [1, 4, 9, 13, 10, 12, 13, 2, 3, 4, 3, 4, 10, 11, 12, 6, 8, 5, 7, 8],
-                      'load_to_sub_pos': [5, 3, 2, 5, 4, 5, 4, 2, 2, 2, 3], 'gen_to_sub_pos': [4, 2, 4, 1, 2],
+                      'load_to_sub_pos': [5, 3, 2, 5, 4, 5, 4, 2, 2, 2, 3],
+                      'gen_to_sub_pos': [4, 2, 4, 1, 2],
                       'line_or_to_sub_pos': [0, 1, 0, 1, 1, 0, 1, 1, 2, 3, 1, 2, 0, 1, 2, 3, 4, 3, 1, 2],
                       'line_ex_to_sub_pos': [0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 1, 2, 1, 1, 2, 0, 2, 3, 0, 3],
                       'load_pos_topo_vect': [8, 12, 55, 18, 23, 29, 39, 42, 45, 48, 52],
                       'gen_pos_topo_vect': [7, 11, 28, 34, 2],
-                      'line_or_pos_topo_vect': [0, 1, 35, 36, 41, 46, 50, 4, 5, 6, 10, 15, 24, 25, 26, 16, 17, 22, 31,
-                                                32],
+                      'line_or_pos_topo_vect': [0, 1, 35, 36, 41, 46, 50, 4, 5, 6, 10, 15, 24, 25, 26, 16, 17, 22,
+                                                31, 32],
                       'line_ex_pos_topo_vect': [3, 19, 40, 53, 43, 49, 54, 9, 13, 20, 14, 21, 44, 47, 51, 30, 37, 27,
                                                 33, 38],
-                      'gen_type': ['solar', 'nuclear', 'nuclear', 'nuclear', 'thermal'],
+                      'gen_type': ['nuclear', 'thermal', 'solar', 'wind', 'thermal'],
                       'gen_pmin': [0.0, 0.0, 0.0, 0.0, 0.0],
-                      'gen_pmax': [50.0, 80.0, 120.0, 120.0, 190.0],
-                      'gen_redispatchable': [False, True, True, True, True],
-                      'gen_max_ramp_up': [50.0, 80.0, 120.0, 120.0, 190.0],
-                      'gen_max_ramp_down': [50.0, 80.0, 120.0, 120.0, 190.0],
-                      'gen_min_uptime': [0, 0, 0, 0, 0],
-                      'gen_min_downtime': [0, 1, 0, 0, 0],
-                      'gen_cost_per_MW': [0.0, 0.0, 0.0, 0.0, 10.0],
-                      'gen_startup_cost': [0.0, 0.0, 0.0, 0.0, 0.0],
-                      'gen_shutdown_cost': [0.0, 0.0, 0.0, 0.0, 0.0],
-                      'subtype': 'grid2op.Observation.CompleteObservation.CompleteObservation',
-                      "grid_layout": None,
-                      'name_shunt': ['shunt_8_0'],
-                      'shunt_to_subid': [8]}
+                      'gen_pmax': [200.0, 200.0, 40.0, 70.0, 400.0],
+                      'gen_redispatchable': [True, True, False, False, True],
+                      'gen_max_ramp_up': [5.0, 10.0, 0.0, 0.0, 10.0],
+                      'gen_max_ramp_down': [5.0, 10.0, 0.0, 0.0, 10.0],
+                      'gen_min_uptime': [96, 4, 0, 0, 4],
+                      'gen_min_downtime': [96, 4, 0, 0, 4],
+                      'gen_cost_per_MW': [5.0, 10.0, 0.0, 0.0, 10.0],
+                      'gen_startup_cost': [20.0, 2.0, 0.0, 0.0, 2.0],
+                      'gen_shutdown_cost': [10.0, 1.0, 0.0, 0.0, 1.0],
+                      'grid_layout': { "sub_0": [-280.0, -81.0], "sub_1": [-100.0,-270.0], "sub_10": [366.0,-270.0],
+                                       "sub_11": [366.0, -54.0], "sub_12": [-64.0,-54.0], "sub_13": [-64.0, 54.0],
+                                       "sub_2": [450.0,0.0], "sub_3": [550.0,0.0], "sub_4": [326.0,54.0],
+                                       "sub_5": [222.0,108.0], "sub_6": [79.0,162.0],"sub_7": [-170.0,270.0],
+                                       "sub_8": [-64.0,270.0], "sub_9": [222.0,216.0]},
+                      'name_shunt': ['shunt_8_0'], 'shunt_to_subid': [8],
+                      '_init_subtype': 'grid2op.Observation.CompleteObservation.CompleteObservation'}
 
         self.dtypes = np.array([dt_int, dt_int, dt_int, dt_int,
                                 dt_int, dt_int, dt_float, dt_float,
@@ -139,16 +92,19 @@ class TestLoadingBackendFunc(unittest.TestCase):
                                 dt_float, dt_float, dt_float,
                                 dt_float, dt_float, dt_float,
                                 dt_float, dt_bool, dt_int, dt_int,
-                                dt_int, dt_int, dt_int,
+                                dt_int, dt_int,
                                 dt_int, dt_int, dt_float, dt_float],
                                dtype=object)
 
         self.dtypes = np.array([np.dtype(el) for el in self.dtypes])
 
         self.shapes = np.array([ 1,  1,  1,  1,  1,  1,  5,  5,  5, 11, 11, 11, 20, 20, 20, 20, 20,
-                                            20, 20, 20, 20, 20, 20, 56, 20, 14, 20, 20, 20,
+                                            20, 20, 20, 20, 20, 20, 56, 20, 14, 20, 20,
                                  5, 5])
-        self.size_obs = 434
+        self.size_obs = 414
+
+    def tearDown(self):
+        self.env.close()
 
     def test_sum_shape_equal_size(self):
         obs = self.env.helper_observation(self.env)
@@ -294,6 +250,7 @@ class TestLoadingBackendFunc(unittest.TestCase):
         assert np.all(vect == vect2)
 
     def test_5_simulate_proper_timestep(self):
+        self.skipTest("This is extensively tested elswhere, and the chronics have been changed.")
         obs_orig = self.env.helper_observation(self.env)
         action = self.env.helper_action_player({})
         action2 = self.env.helper_action_player({})
@@ -325,11 +282,11 @@ class TestLoadingBackendFunc(unittest.TestCase):
         obs = self.env.helper_observation(self.env)
         dict_ = obs.state_of(load_id=0)
         assert "p" in dict_
-        assert np.abs(dict_["p"] - 18.8) <= self.tol_one
+        assert np.abs(dict_["p"] - 21.2) <= self.tol_one
         assert "q" in dict_
-        assert np.abs(dict_["q"] - 13.4) <= self.tol_one
+        assert np.abs(dict_["q"] - 14.9) <= self.tol_one
         assert "v" in dict_
-        assert np.abs(dict_["v"] - 141.075) <= self.tol_one
+        assert np.abs(dict_["v"] - 142.1) <= self.tol_one
         assert "bus" in dict_
         assert dict_["bus"] == 1
         assert "sub_id" in dict_
@@ -339,11 +296,11 @@ class TestLoadingBackendFunc(unittest.TestCase):
         obs = self.env.helper_observation(self.env)
         dict_ = obs.state_of(gen_id=0)
         assert "p" in dict_
-        assert dict_["p"] == 0.0
+        assert np.abs(dict_["p"] - 93.6) <= self.tol_one
         assert "q" in dict_
-        assert np.abs(dict_["q"] - 47.48287) <= self.tol_one
+        assert np.abs(dict_["q"] - 65.49697) <= self.tol_one
         assert "v" in dict_
-        assert np.abs(dict_["v"] - 141.075) <= self.tol_one
+        assert np.abs(dict_["v"] - 142.1) <= self.tol_one
         assert "bus" in dict_
         assert dict_["bus"] == 1
         assert "sub_id" in dict_
@@ -355,11 +312,11 @@ class TestLoadingBackendFunc(unittest.TestCase):
         assert "origin" in dict_both
         dict_ = dict_both["origin"]
         assert "p" in dict_
-        assert np.abs(dict_["p"] - 109.77537) <= self.tol_one
+        assert np.abs(dict_["p"] - 39.33145) <= self.tol_one
         assert "q" in dict_
-        assert np.abs(dict_["q"] - -8.71631) <= self.tol_one
+        assert np.abs(dict_["q"] - -15.304552) <= self.tol_one
         assert "v" in dict_
-        assert np.abs(dict_["v"] - 143.1) <= self.tol_one
+        assert np.abs(dict_["v"] - 142.1) <= self.tol_one
         assert "bus" in dict_
         assert dict_["bus"] == 1
         assert "sub_id" in dict_
@@ -368,11 +325,11 @@ class TestLoadingBackendFunc(unittest.TestCase):
         assert "extremity" in dict_both
         dict_ = dict_both["extremity"]
         assert "p" in dict_
-        assert np.abs(dict_["p"] - -107.69115) <= self.tol_one
+        assert np.abs(dict_["p"] - -39.034054) <= self.tol_one
         assert "q" in dict_
-        assert np.abs(dict_["q"] - 9.230471) <= self.tol_one
+        assert np.abs(dict_["q"] - 10.362568) <= self.tol_one
         assert "v" in dict_
-        assert np.abs(dict_["v"] - 141.075) <= self.tol_one
+        assert np.abs(dict_["v"] - 142.1) <= self.tol_one
         assert "bus" in dict_
         assert dict_["bus"] == 1
         assert "sub_id" in dict_
@@ -401,7 +358,8 @@ class TestLoadingBackendFunc(unittest.TestCase):
 
     def test_to_dict(self):
         dict_ = self.env.helper_observation.to_dict()
-        assert dict_ == self.dict_
+        self.maxDiff = None
+        self.assertDictEqual(dict_, self.dict_)
 
     def test_from_dict(self):
         res = ObservationSpace.from_dict(self.dict_)
@@ -421,7 +379,7 @@ class TestLoadingBackendFunc(unittest.TestCase):
         assert np.all(res.gen_pos_topo_vect == self.env.helper_observation.gen_pos_topo_vect)
         assert np.all(res.line_or_pos_topo_vect == self.env.helper_observation.line_or_pos_topo_vect)
         assert np.all(res.line_ex_pos_topo_vect == self.env.helper_observation.line_ex_pos_topo_vect)
-        assert np.all(res.observationClass == self.env.helper_observation.observationClass)
+        assert issubclass(res.observationClass, self.env.helper_observation._init_subtype)
 
     def test_json_serializable(self):
         dict_ = self.env.helper_observation.to_dict()
@@ -448,7 +406,7 @@ class TestLoadingBackendFunc(unittest.TestCase):
         assert np.all(res.gen_pos_topo_vect == self.env.helper_observation.gen_pos_topo_vect)
         assert np.all(res.line_or_pos_topo_vect == self.env.helper_observation.line_or_pos_topo_vect)
         assert np.all(res.line_ex_pos_topo_vect == self.env.helper_observation.line_ex_pos_topo_vect)
-        assert np.all(res.observationClass == self.env.helper_observation.observationClass)
+        assert issubclass(res.observationClass, self.env.helper_observation._init_subtype)
 
 
 class TestObservationHazard(unittest.TestCase):
@@ -515,19 +473,23 @@ class TestObservationHazard(unittest.TestCase):
                                chronics_handler=self.chronics_handler,
                                parameters=self.env_params,
                                names_chronics_to_backend=self.names_chronics_to_backend,
-                               rewardClass=self.rewardClass)
+                               rewardClass=self.rewardClass,
+                               name="test_obs_env1")
+
+    def tearDown(self) -> None:
+        self.env.close()
 
     def test_1_generating_obs_withhazard(self):
         # test that helper_obs is abl to generate a valid observation
         obs = self.env.get_obs()
-        assert np.all(obs.time_before_line_reconnectable == [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
+        assert np.all(obs.time_before_cooldown_line == [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
         action = self.env.helper_action_player({})
         _ = self.env.step(action)
         obs = self.env.get_obs()
-        assert np.all(obs.time_before_line_reconnectable == [0, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
+        assert np.all(obs.time_before_cooldown_line == [0, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
         _ = self.env.step(action)
         obs = self.env.get_obs()
-        assert np.all(obs.time_before_line_reconnectable == [0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
+        assert np.all(obs.time_before_cooldown_line == [0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
 
 
 class TestObservationMaintenance(unittest.TestCase):
@@ -594,7 +556,11 @@ class TestObservationMaintenance(unittest.TestCase):
                                chronics_handler=self.chronics_handler,
                                parameters=self.env_params,
                                names_chronics_to_backend=self.names_chronics_to_backend,
-                               rewardClass=self.rewardClass)
+                               rewardClass=self.rewardClass,
+                               name="test_obs_env2")
+
+    def tearDown(self) -> None:
+        self.env.close()
 
     def test_1_generating_obs_withmaintenance(self):
         # test that helper_obs is abl to generate a valid observation
@@ -620,17 +586,16 @@ class TestObservationMaintenance(unittest.TestCase):
 
 class TestUpdateEnvironement(unittest.TestCase):
     def setUp(self):
-
         # Create env and obs in left hand
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            self.lenv = make_new("rte_case5_example", test=True)
+            self.lenv = make("rte_case5_example", test=True)
             self.lobs = self.lenv.reset()
 
         # Create env and obs in right hand
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            self.renv = make_new("rte_case5_example", test=True)
+            self.renv = make("rte_case5_example", test=True)
             # Step once to make it different
             self.robs, _, _, _ = self.renv.step(self.renv.action_space())
 
@@ -709,7 +674,7 @@ class TestUpdateEnvironement(unittest.TestCase):
         # Check left cooldowns are updated to the rhs CDs
         assert np.all(self.lobs.time_before_cooldown_line == self.robs.time_before_cooldown_line)
         assert np.all(self.lobs.time_before_cooldown_sub == self.robs.time_before_cooldown_sub)
-        assert np.all(self.lobs.time_before_line_reconnectable == self.robs.time_before_line_reconnectable)
+        assert np.all(self.lobs.time_before_cooldown_line == self.robs.time_before_cooldown_line)
         assert np.all(self.lobs.time_next_maintenance == self.robs.time_next_maintenance)
         assert np.all(self.lobs.duration_next_maintenance == self.robs.duration_next_maintenance)
 
@@ -724,7 +689,7 @@ class TestSimulateEqualsStep(unittest.TestCase):
         # Create env
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            self.env = make_new("rte_case14_realistic", test=True)
+            self.env = make("rte_case14_realistic", test=True)
 
         # Set forecasts to actual values so that simulate runs on the same numbers as step
         self.env.chronics_handler.real_data.data.prod_p_forecast = np.roll(self.env.chronics_handler.real_data.data.prod_p, -1, axis=0)
@@ -744,7 +709,7 @@ class TestSimulateEqualsStep(unittest.TestCase):
         donothing_act = self.env.action_space()
         # Simulate & Step
         self.sim_obs, _, _, _ = self.obs.simulate(donothing_act)
-        self.step_obs, _, _, _ = self.env.step(donothing_act)        
+        self.step_obs, _, _, _ = self.env.step(donothing_act)
         # Test observations are the same
         assert self.sim_obs == self.step_obs
 
@@ -1041,6 +1006,15 @@ class TestSimulateEqualsStep(unittest.TestCase):
         # Test observations are the same
         assert self.sim_obs == self.step_obs
 
+    def test_forecasted_inj(self):
+        sim_obs, _, _, _ = self.obs.simulate(self.env.action_space())
+        prod_p_f, prod_v_f, load_p_f, load_q_f = self.obs.get_forecasted_inj()
+        assert np.sum(np.abs(prod_v_f - sim_obs.prod_v)) < 1e-5
+        assert np.sum(np.abs(load_p_f - sim_obs.load_p)) < 1e-5
+        assert np.sum(np.abs(load_q_f - sim_obs.load_q)) < 1e-5
+        # test all prod p are equal, of course we remove the slack bus...
+        assert np.sum(np.abs(prod_p_f[:-1] - sim_obs.prod_p[:-1])) < 1e-5
+
 ## TODO test -- Add test to cover simulation vs step when there is a planned maintenance operation
 
         
